@@ -611,7 +611,7 @@ impl State {
                 return Ok(());
             }
             _ => debug!("Configuring (and rendering) main window"),
-        };
+        }
 
         let CalculatedDimensions {
             window_width,
@@ -843,7 +843,7 @@ impl State {
             if let Err(err) = scheduler.schedule(rx) {
                 self.futures.fetch_sub(1, Ordering::Release);
                 bail!(err);
-            };
+            }
         }
         Ok(())
     }
@@ -915,7 +915,7 @@ fn image_encoded_cb(maybe_png: Result<Vec<u8>, Canceled>, _: &mut (), state: &mu
             error!("Encoding error: {}", e);
             state.png = PngState::Failed;
         }
-    };
+    }
 }
 
 impl ProvidesRegistryState for State {
@@ -975,7 +975,7 @@ impl Dispatch<wl_surface::WlSurface, Window> for State {
                 Scale::Fractional(_) => {}
             },
             _ => (),
-        };
+        }
     }
 }
 
@@ -990,7 +990,7 @@ impl Dispatch<wp_fractional_scale_v1::WpFractionalScaleV1, Window> for State {
     ) {
         if let wp_fractional_scale_v1::Event::PreferredScale { scale } = event {
             state.scale = Scale::Fractional(scale);
-        };
+        }
     }
 }
 
@@ -1033,7 +1033,7 @@ impl Dispatch<wl_surface::WlSurface, OutputDetectorSurface> for State {
             state.detector.layer_surface.destroy();
             state.detector.surface.destroy();
             state.detector.buffer.destroy();
-        };
+        }
     }
 }
 
@@ -1269,6 +1269,7 @@ impl KeyboardHandler for State {
         _: &wl_keyboard::WlKeyboard,
         _: u32,
         event: smithay_client_toolkit::seat::keyboard::Modifiers,
+        _layout: u32,
     ) {
         self.ctrl = event.ctrl;
     }
@@ -1380,11 +1381,11 @@ impl Dispatch<ZwlrScreencopyFrameV1, ()> for State {
                 if let Err(err) = state.encode_image_to_png() {
                     error!("Error encoding image into PNG: {}", err);
                     state.png = PngState::Failed;
-                };
+                }
                 if let Err(err) = state.show_screenshot_thumbnail(frame) {
                     error!("Error rendering thumbnail: {}", err);
                     state.window = WindowState::Closed;
-                };
+                }
             }
             zwlr_screencopy_frame_v1::Event::Failed => {
                 // Example scenario: Phone running Phosh, tried to take screenshot via SSH
@@ -1447,12 +1448,12 @@ impl Dispatch<wl_data_source::WlDataSource, ()> for State {
                     state.paste_as_png(fd);
                 } else {
                     warn!("Tried to paste as unknown mime-type: {}", mime_type);
-                };
+                }
             }
             wl_data_source::Event::Cancelled => {
                 if Some(data_source) == state.current_selection.as_ref() {
                     state.current_selection = None;
-                };
+                }
             }
             wl_data_source::Event::Target { .. }
             | wl_data_source::Event::DndDropPerformed
